@@ -1,4 +1,6 @@
 /*
+ *  arch-tag: Implementation of simple Rhythmbox debugging interface
+ *
  *  Copyright (C) 2002 Jorn Baayen
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -17,7 +19,6 @@
  *
  *  NOTES: log domain hack stolen from nautilus
  *
- *  $Id: rb-debug.c,v 1.4 2003/08/11 06:38:46 cwalters Exp $
  */
 
 #include <glib.h>
@@ -93,6 +94,7 @@ rb_debug_init (gboolean debug)
 		"GLib-GObject",
 		"GModule",
 		"GThread",
+		"GStreamer",
 		"Gdk",
 		"Gdk-Pixbuf",
 		"GdkPixbuf",
@@ -107,6 +109,7 @@ rb_debug_init (gboolean debug)
 		"GnomeVFSMonikers",
 		"Gtk",
 		"Rhythmbox",
+		"RhythmDB",
 		"MonkeyMedia",
 		"ORBit",
 		"ZVT",
@@ -119,10 +122,9 @@ rb_debug_init (gboolean debug)
 
 	debugging = debug;
 
-	for (i = 0; i < G_N_ELEMENTS (standard_log_domains); i++)
-	{
-		g_log_set_handler (standard_log_domains[i], G_LOG_LEVEL_MASK, log_handler, NULL);
-	}
+	if (debugging)
+		for (i = 0; i < G_N_ELEMENTS (standard_log_domains); i++)
+			g_log_set_handler (standard_log_domains[i], G_LOG_LEVEL_MASK, log_handler, NULL);
 
 	rb_debug ("Debugging enabled");
 }
